changeset 13982:052aee037835

[gaim-migrate @ 16550] Only set an account's status to the default status when enabling it, not when disabling it. Fixes a very minor weirdness. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Sun, 23 Jul 2006 18:58:59 +0000
parents 91a4cc3ee221
children b7a99d54a5a9
files src/gtkaccount.c
diffstat 1 files changed, 9 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/gtkaccount.c	Sun Jul 23 18:57:08 2006 +0000
+++ b/src/gtkaccount.c	Sun Jul 23 18:58:59 2006 +0000
@@ -2221,9 +2221,15 @@
 					   COLUMN_ENABLED, &enabled,
 					   -1);
 
-	/* Set the statuses for this account to the current status */
-	saved_status = gaim_savedstatus_get_current();
-	gaim_savedstatus_activate_for_account(saved_status, account);
+	/*
+	 * If we just enabled the account, then set the statuses
+	 * to the current status.
+	 */
+	if (!enabled)
+	{
+		saved_status = gaim_savedstatus_get_current();
+		gaim_savedstatus_activate_for_account(saved_status, account);
+	}
 
 	gaim_account_set_enabled(account, GAIM_GTK_UI, !enabled);
 }